Class: Google::Apis::CloudassetV1::EffectiveTagDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

The effective tags and the ancestor resources from which they were inherited.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EffectiveTagDetails

Returns a new instance of EffectiveTagDetails.



1063
1064
1065
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attached_resourceString

The full resource name of the ancestor from which effective_tags are inherited, according to tag inheritance. Corresponds to the JSON property attachedResource

Returns:

  • (String)


1050
1051
1052
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1050

def attached_resource
  @attached_resource
end

#effective_tagsArray<Google::Apis::CloudassetV1::Tag>

The effective tags inherited from the attached_resource. Note that tags with the same key but different values may attach to resources at a different hierarchy levels. The lower hierarchy tag value will overwrite the higher hierarchy tag value of the same tag key. In this case, the tag value at the higher hierarchy level will be removed. For more information, see tag inheritance. Corresponds to the JSON property effectiveTags



1061
1062
1063
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1061

def effective_tags
  @effective_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1068
1069
1070
1071
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1068

def update!(**args)
  @attached_resource = args[:attached_resource] if args.key?(:attached_resource)
  @effective_tags = args[:effective_tags] if args.key?(:effective_tags)
end