Class: Google::Apis::CloudassetV1::GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

The Google Cloud resources governed by the organization policies of the AnalyzeOrgPolicyGovernedAssetsRequest.constraint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedResource

Returns a new instance of GoogleCloudAssetV1AnalyzeOrgPolicyGovernedAssetsResponseGovernedResource.



1661
1662
1663
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_typeString

The asset type of the AnalyzeOrgPolicyGovernedAssetsResponse.GovernedResource. full_resource_name Example: cloudresourcemanager.googleapis.com/Project See Cloud Asset Inventory Supported Asset Types for all supported asset types. Corresponds to the JSON property assetType

Returns:

  • (String)


1620
1621
1622
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1620

def asset_type
  @asset_type
end

#effective_tagsArray<Google::Apis::CloudassetV1::EffectiveTagDetails>

The effective tags on this resource. Corresponds to the JSON property effectiveTags



1625
1626
1627
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1625

def effective_tags
  @effective_tags
end

#foldersArray<String>

The folder(s) that this resource belongs to, in the format of folders/ FOLDER_NUMBER. This field is available when the resource belongs (directly or cascadingly) to one or more folders. Corresponds to the JSON property folders

Returns:

  • (Array<String>)


1632
1633
1634
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1632

def folders
  @folders
end

#full_resource_nameString

The full resource name of the Google Cloud resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1638

def full_resource_name
  @full_resource_name
end

#organizationString

The organization that this resource belongs to, in the format of organizations/ ORGANIZATION_NUMBER. This field is available when the resource belongs ( directly or cascadingly) to an organization. Corresponds to the JSON property organization

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1645

def organization
  @organization
end

#parentString

The full resource name of the parent of AnalyzeOrgPolicyGovernedAssetsResponse. GovernedResource.full_resource_name. Corresponds to the JSON property parent

Returns:

  • (String)


1652
1653
1654
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1652

def parent
  @parent
end

#projectString

The project that this resource belongs to, in the format of projects/ PROJECT_NUMBER. This field is available when the resource belongs to a project. Corresponds to the JSON property project

Returns:

  • (String)


1659
1660
1661
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1659

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1666

def update!(**args)
  @asset_type = args[:asset_type] if args.key?(:asset_type)
  @effective_tags = args[:effective_tags] if args.key?(:effective_tags)
  @folders = args[:folders] if args.key?(:folders)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @project = args[:project] if args.key?(:project)
end