Class: Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressSource
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
The source that IngressPolicy authorizes access from.
Instance Attribute Summary collapse
-
#access_level ⇒ String
An AccessLevel resource name that allow resources within the ServicePerimeters to be accessed from the internet.
-
#psc_endpoint ⇒ Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
Specifies the PSC an API call refers to.
-
#resource ⇒ String
A Google Cloud resource that is allowed to ingress the perimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressSource
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1IngressSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressSource
Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressSource.
3537 3538 3539 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_level ⇒ String
An AccessLevel resource name that allow resources within the ServicePerimeters
to be accessed from the internet. AccessLevels listed must be in the same
policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will
cause an error. If no AccessLevel names are listed, resources within the
perimeter can only be accessed via Google Cloud calls with request origins
within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL
. If a single * is specified for access_level, then all IngressSources
will be allowed.
Corresponds to the JSON property accessLevel
3519 3520 3521 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3519 def access_level @access_level end |
#psc_endpoint ⇒ Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
Specifies the PSC an API call refers to.
Corresponds to the JSON property pscEndpoint
3524 3525 3526 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3524 def psc_endpoint @psc_endpoint end |
#resource ⇒ String
A Google Cloud resource that is allowed to ingress the perimeter. Requests
from these resources will be allowed to access perimeter data. Currently only
projects and VPCs are allowed. Project format: projects/project_numberVPC
network format: `//compute.googleapis.com/projects/`PROJECT_ID`/global/
networks/`NAME. The project may be in any Google Cloud organization, not
just the organization that the perimeter is defined in. * is not allowed,
the case of allowing all Google Cloud resources only is not supported.
Corresponds to the JSON property resource
3535 3536 3537 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3535 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3542 3543 3544 3545 3546 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3542 def update!(**args) @access_level = args[:access_level] if args.key?(:access_level) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @resource = args[:resource] if args.key?(:resource) end |