Class: Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1MethodSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

An allowed method or permission of a service specified in ApiOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1MethodSelector

Returns a new instance of GoogleIdentityAccesscontextmanagerV1MethodSelector.



3568
3569
3570
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

A valid method name for the corresponding service_name in ApiOperation. If * is used as the value for the method, then ALL methods and permissions are allowed. Corresponds to the JSON property method

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3560

def method_prop
  @method_prop
end

#permissionString

A valid Cloud IAM permission for the corresponding service_name in ApiOperation. Corresponds to the JSON property permission

Returns:

  • (String)


3566
3567
3568
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3566

def permission
  @permission
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3573
3574
3575
3576
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3573

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @permission = args[:permission] if args.key?(:permission)
end