Class: Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
Specifies the Private Service Connect endpoint that an API call refers to.
Instance Attribute Summary collapse
-
#forwarding_rule ⇒ String
The full resource name of the global forwarding rule that identifies a Private Service Connect endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
Returns a new instance of GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint.
3683 3684 3685 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarding_rule ⇒ String
The full resource name of the global forwarding rule that identifies a Private
Service Connect endpoint. Forwarding rule format: //compute.googleapis.com/
projects/PROJECT_ID/global/forwardingRules/FORWARDING_RULE_ID`.
Corresponds to the JSON propertyforwardingRule`
3681 3682 3683 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3681 def forwarding_rule @forwarding_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3688 3689 3690 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3688 def update!(**args) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) end |