Class: Google::Apis::CloudassetV1::IamPolicyAnalysisQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

IAM policy analysis query message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IamPolicyAnalysisQuery

Returns a new instance of IamPolicyAnalysisQuery.



4092
4093
4094
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_selectorGoogle::Apis::CloudassetV1::AccessSelector

Specifies roles and/or permissions to analyze, to determine both the identities possessing them and the resources they control. If multiple values are specified, results will include roles or permissions matching any of them. The total number of roles and permissions should be equal or less than 10. Corresponds to the JSON property accessSelector



4053
4054
4055
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4053

def access_selector
  @access_selector
end

#condition_contextGoogle::Apis::CloudassetV1::ConditionContext

The IAM conditions context. Corresponds to the JSON property conditionContext



4058
4059
4060
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4058

def condition_context
  @condition_context
end

#identity_selectorGoogle::Apis::CloudassetV1::IdentitySelector

Specifies an identity for which to determine resource access, based on roles assigned either directly to them or to the groups they belong to, directly or indirectly. Corresponds to the JSON property identitySelector



4065
4066
4067
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4065

def identity_selector
  @identity_selector
end

#optionsGoogle::Apis::CloudassetV1::Options

Contains query options. Corresponds to the JSON property options



4070
4071
4072
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4070

def options
  @options
end

#resource_selectorGoogle::Apis::CloudassetV1::ResourceSelector

Specifies the resource to analyze for access policies, which may be set directly on the resource, or on ancestors such as organizations, folders or projects. Corresponds to the JSON property resourceSelector



4077
4078
4079
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4077

def resource_selector
  @resource_selector
end

#scopeString

Required. The relative name of the root asset. Only resources and IAM policies within the scope will be analyzed. This can only be an organization number ( such as "organizations/123"), a folder number (such as "folders/123"), a project ID (such as "projects/my-project-id"), or a project number (such as " projects/12345"). To know how to get organization ID, visit here . To know how to get folder or project ID, visit here . Corresponds to the JSON property scope

Returns:

  • (String)


4090
4091
4092
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4090

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4097
4098
4099
4100
4101
4102
4103
4104
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4097

def update!(**args)
  @access_selector = args[:access_selector] if args.key?(:access_selector)
  @condition_context = args[:condition_context] if args.key?(:condition_context)
  @identity_selector = args[:identity_selector] if args.key?(:identity_selector)
  @options = args[:options] if args.key?(:options)
  @resource_selector = args[:resource_selector] if args.key?(:resource_selector)
  @scope = args[:scope] if args.key?(:scope)
end