Class: Google::Apis::CloudassetV1::IamPolicyAnalysisResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

IAM Policy analysis result, consisting of one IAM policy binding and derived access control lists.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IamPolicyAnalysisResult

Returns a new instance of IamPolicyAnalysisResult.



4140
4141
4142
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_control_listsArray<Google::Apis::CloudassetV1::GoogleCloudAssetV1AccessControlList>

The access control lists derived from the iam_binding that match or potentially match resource and access selectors specified in the request. Corresponds to the JSON property accessControlLists



4116
4117
4118
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4116

def access_control_lists
  @access_control_lists
end

#attached_resource_full_nameString

The full resource name of the resource to which the iam_binding policy attaches. Corresponds to the JSON property attachedResourceFullName

Returns:

  • (String)


4122
4123
4124
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4122

def attached_resource_full_name
  @attached_resource_full_name
end

#fully_exploredBoolean Also known as: fully_explored?

Represents whether all analyses on the iam_binding have successfully finished. Corresponds to the JSON property fullyExplored

Returns:

  • (Boolean)


4127
4128
4129
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4127

def fully_explored
  @fully_explored
end

#iam_bindingGoogle::Apis::CloudassetV1::Binding

Associates members, or principals, with a role. Corresponds to the JSON property iamBinding



4133
4134
4135
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4133

def iam_binding
  @iam_binding
end

#identity_listGoogle::Apis::CloudassetV1::GoogleCloudAssetV1IdentityList

The identities and group edges. Corresponds to the JSON property identityList



4138
4139
4140
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4138

def identity_list
  @identity_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4145
4146
4147
4148
4149
4150
4151
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4145

def update!(**args)
  @access_control_lists = args[:access_control_lists] if args.key?(:access_control_lists)
  @attached_resource_full_name = args[:attached_resource_full_name] if args.key?(:attached_resource_full_name)
  @fully_explored = args[:fully_explored] if args.key?(:fully_explored)
  @iam_binding = args[:iam_binding] if args.key?(:iam_binding)
  @identity_list = args[:identity_list] if args.key?(:identity_list)
end