Class: Google::Apis::CloudassetV1::Inventory

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

This API resource represents the available inventory data for a Compute Engine virtual machine (VM) instance at a given point in time. You can use this API resource to determine the inventory data of your VM. For more information, see Information provided by OS inventory management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Inventory

Returns a new instance of Inventory.



4342
4343
4344
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsHash<String,Google::Apis::CloudassetV1::Item>

Inventory items related to the VM keyed by an opaque unique identifier for each inventory item. The identifier is unique to each distinct and addressable inventory item and will change, when there is a new package version. Corresponds to the JSON property items

Returns:



4324
4325
4326
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4324

def items
  @items
end

#nameString

Output only. The Inventory API resource name. Format: projects/ project_number/locations/location/instances/instance_id/inventory Corresponds to the JSON property name

Returns:

  • (String)


4330
4331
4332
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4330

def name
  @name
end

#os_infoGoogle::Apis::CloudassetV1::OsInfo

Operating system information for the VM. Corresponds to the JSON property osInfo



4335
4336
4337
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4335

def os_info
  @os_info
end

#update_timeString

Output only. Timestamp of the last reported inventory for the VM. Corresponds to the JSON property updateTime

Returns:

  • (String)


4340
4341
4342
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4340

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4347
4348
4349
4350
4351
4352
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4347

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @name = args[:name] if args.key?(:name)
  @os_info = args[:os_info] if args.key?(:os_info)
  @update_time = args[:update_time] if args.key?(:update_time)
end