Class: Google::Apis::CloudassetV1::Item
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::Item
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
A single piece of inventory on a VM.
Instance Attribute Summary collapse
-
#available_package ⇒ Google::Apis::CloudassetV1::SoftwarePackage
Software package information of the operating system.
-
#create_time ⇒ String
When this inventory item was first detected.
-
#id ⇒ String
Identifier for this item, unique across items for this VM.
-
#installed_package ⇒ Google::Apis::CloudassetV1::SoftwarePackage
Software package information of the operating system.
-
#origin_type ⇒ String
The origin of this inventory item.
-
#type ⇒ String
The specific type of inventory, correlating to its specific details.
-
#update_time ⇒ String
When this inventory item was last modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Item
constructor
A new instance of Item.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Item
Returns a new instance of Item.
4271 4272 4273 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_package ⇒ Google::Apis::CloudassetV1::SoftwarePackage
Software package information of the operating system.
Corresponds to the JSON property availablePackage
4239 4240 4241 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4239 def available_package @available_package end |
#create_time ⇒ String
When this inventory item was first detected.
Corresponds to the JSON property createTime
4244 4245 4246 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4244 def create_time @create_time end |
#id ⇒ String
Identifier for this item, unique across items for this VM.
Corresponds to the JSON property id
4249 4250 4251 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4249 def id @id end |
#installed_package ⇒ Google::Apis::CloudassetV1::SoftwarePackage
Software package information of the operating system.
Corresponds to the JSON property installedPackage
4254 4255 4256 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4254 def installed_package @installed_package end |
#origin_type ⇒ String
The origin of this inventory item.
Corresponds to the JSON property originType
4259 4260 4261 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4259 def origin_type @origin_type end |
#type ⇒ String
The specific type of inventory, correlating to its specific details.
Corresponds to the JSON property type
4264 4265 4266 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4264 def type @type end |
#update_time ⇒ String
When this inventory item was last modified.
Corresponds to the JSON property updateTime
4269 4270 4271 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4269 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4276 4277 4278 4279 4280 4281 4282 4283 4284 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4276 def update!(**args) @available_package = args[:available_package] if args.key?(:available_package) @create_time = args[:create_time] if args.key?(:create_time) @id = args[:id] if args.key?(:id) @installed_package = args[:installed_package] if args.key?(:installed_package) @origin_type = args[:origin_type] if args.key?(:origin_type) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |