Class: Google::Apis::CloudassetV1::ListAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

ListAssets response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssetsResponse

Returns a new instance of ListAssetsResponse.



4431
4432
4433
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetsArray<Google::Apis::CloudassetV1::Asset>

Assets. Corresponds to the JSON property assets



4417
4418
4419
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4417

def assets
  @assets
end

#next_page_tokenString

Token to retrieve the next page of results. It expires 72 hours after the page token for the first page is generated. Set to empty if there are no remaining results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4424
4425
4426
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4424

def next_page_token
  @next_page_token
end

#read_timeString

Time the snapshot was taken. Corresponds to the JSON property readTime

Returns:

  • (String)


4429
4430
4431
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4429

def read_time
  @read_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4436
4437
4438
4439
4440
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4436

def update!(**args)
  @assets = args[:assets] if args.key?(:assets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @read_time = args[:read_time] if args.key?(:read_time)
end