Class: Google::Apis::CloudassetV1::OrgPolicyResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

The organization policy result to the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrgPolicyResult

Returns a new instance of OrgPolicyResult.



4775
4776
4777
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consolidated_policyGoogle::Apis::CloudassetV1::AnalyzerOrgPolicy

This organization policy message is a modified version of the one defined in the Organization Policy system. This message contains several fields defined in the original organization policy with some new fields for analysis purpose. Corresponds to the JSON property consolidatedPolicy



4745
4746
4747
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4745

def consolidated_policy
  @consolidated_policy
end

#foldersArray<String>

The folder(s) that this consolidated policy belongs to, in the format of folders/FOLDER_NUMBER. This field is available when the consolidated policy belongs (directly or cascadingly) to one or more folders. Corresponds to the JSON property folders

Returns:

  • (Array<String>)


4752
4753
4754
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4752

def folders
  @folders
end

#organizationString

The organization that this consolidated policy belongs to, in the format of organizations/ORGANIZATION_NUMBER. This field is available when the consolidated policy belongs (directly or cascadingly) to an organization. Corresponds to the JSON property organization

Returns:

  • (String)


4759
4760
4761
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4759

def organization
  @organization
end

#policy_bundleArray<Google::Apis::CloudassetV1::AnalyzerOrgPolicy>

The ordered list of all organization policies from the consolidated_policy. attached_resource. to the scope specified in the request. If the constraint is defined with default policy, it will also appear in the list. Corresponds to the JSON property policyBundle



4766
4767
4768
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4766

def policy_bundle
  @policy_bundle
end

#projectString

The project that this consolidated policy belongs to, in the format of projects/PROJECT_NUMBER. This field is available when the consolidated policy belongs to a project. Corresponds to the JSON property project

Returns:

  • (String)


4773
4774
4775
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4773

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4780
4781
4782
4783
4784
4785
4786
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4780

def update!(**args)
  @consolidated_policy = args[:consolidated_policy] if args.key?(:consolidated_policy)
  @folders = args[:folders] if args.key?(:folders)
  @organization = args[:organization] if args.key?(:organization)
  @policy_bundle = args[:policy_bundle] if args.key?(:policy_bundle)
  @project = args[:project] if args.key?(:project)
end