Class: Google::Apis::CloudassetV1::RelationshipAttributes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

DEPRECATED. This message only presents for the purpose of backward- compatibility. The server will never populate this message in responses. The relationship attributes which include type, source_resource_type, target_resource_type and action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelationshipAttributes

Returns a new instance of RelationshipAttributes.



5320
5321
5322
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The detail of the relationship, e.g. contains, attaches Corresponds to the JSON property action

Returns:

  • (String)


5302
5303
5304
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5302

def action
  @action
end

#source_resource_typeString

The source asset type. Example: compute.googleapis.com/Instance Corresponds to the JSON property sourceResourceType

Returns:

  • (String)


5307
5308
5309
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5307

def source_resource_type
  @source_resource_type
end

#target_resource_typeString

The target asset type. Example: compute.googleapis.com/Disk Corresponds to the JSON property targetResourceType

Returns:

  • (String)


5312
5313
5314
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5312

def target_resource_type
  @target_resource_type
end

#typeString

The unique identifier of the relationship type. Example: INSTANCE_TO_INSTANCEGROUP Corresponds to the JSON property type

Returns:

  • (String)


5318
5319
5320
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5318

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5325
5326
5327
5328
5329
5330
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5325

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @source_resource_type = args[:source_resource_type] if args.key?(:source_resource_type)
  @target_resource_type = args[:target_resource_type] if args.key?(:target_resource_type)
  @type = args[:type] if args.key?(:type)
end