Class: Google::Apis::CloudassetV1::Resource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

A representation of a Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



5510
5511
5512
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

The content of the resource, in which some sensitive fields are removed and may not be present. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


5464
5465
5466
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5464

def data
  @data
end

#discovery_document_uriString

The URL of the discovery document containing the resource's JSON schema. Example: https://www.googleapis.com/discovery/v1/apis/compute/v1/rest This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryDocumentUri

Returns:

  • (String)


5472
5473
5474
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5472

def discovery_document_uri
  @discovery_document_uri
end

#discovery_nameString

The JSON schema name listed in the discovery document. Example: Project This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryName

Returns:

  • (String)


5479
5480
5481
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5479

def discovery_name
  @discovery_name
end

#locationString

The location of the resource in Google Cloud, such as its zone and region. For more information, see https://cloud.google.com/about/locations/. Corresponds to the JSON property location

Returns:

  • (String)


5485
5486
5487
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5485

def location
  @location
end

#parentString

The full name of the immediate parent of this resource. See Resource Names for more information. For Google Cloud assets, this value is the parent resource defined in the IAM policy hierarchy. Example: //cloudresourcemanager.googleapis.com/ projects/my_project_123 Corresponds to the JSON property parent

Returns:

  • (String)


5495
5496
5497
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5495

def parent
  @parent
end

#resource_urlString

The REST URL for accessing the resource. An HTTP GET request using this URL returns the resource itself. Example: https://cloudresourcemanager.googleapis. com/v1/projects/my-project-123 This value is unspecified for resources without a REST API. Corresponds to the JSON property resourceUrl

Returns:

  • (String)


5503
5504
5505
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5503

def resource_url
  @resource_url
end

#versionString

The API version. Example: v1 Corresponds to the JSON property version

Returns:

  • (String)


5508
5509
5510
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5508

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5515
5516
5517
5518
5519
5520
5521
5522
5523
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5515

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @discovery_document_uri = args[:discovery_document_uri] if args.key?(:discovery_document_uri)
  @discovery_name = args[:discovery_name] if args.key?(:discovery_name)
  @location = args[:location] if args.key?(:location)
  @parent = args[:parent] if args.key?(:parent)
  @resource_url = args[:resource_url] if args.key?(:resource_url)
  @version = args[:version] if args.key?(:version)
end