Class: Google::Apis::CloudassetV1::SearchAllIamPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

Search all IAM policies response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchAllIamPoliciesResponse

Returns a new instance of SearchAllIamPoliciesResponse.



5982
5983
5984
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Set if there are more results than those appearing in this response; to get the next set of results, call this method again, using this value as the page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5974
5975
5976
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5974

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::CloudassetV1::IamPolicySearchResult>

A list of IAM policies that match the search query. Related information such as the associated resource is returned along with the policy. Corresponds to the JSON property results



5980
5981
5982
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5980

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5987
5988
5989
5990
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5987

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
end