Class: Google::Apis::CloudassetV1::SoftwarePackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

Software package information of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwarePackage

Returns a new instance of SoftwarePackage.



5959
5960
5961
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apt_packageGoogle::Apis::CloudassetV1::VersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property aptPackage



5906
5907
5908
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5906

def apt_package
  @apt_package
end

#cos_packageGoogle::Apis::CloudassetV1::VersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property cosPackage



5912
5913
5914
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5912

def cos_package
  @cos_package
end

#googet_packageGoogle::Apis::CloudassetV1::VersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property googetPackage



5918
5919
5920
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5918

def googet_package
  @googet_package
end

#qfe_packageGoogle::Apis::CloudassetV1::WindowsQuickFixEngineeringPackage

Information related to a Quick Fix Engineering package. Fields are taken from Windows QuickFixEngineering Interface and match the source names: https://docs. microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering Corresponds to the JSON property qfePackage



5925
5926
5927
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5925

def qfe_package
  @qfe_package
end

#windows_applicationGoogle::Apis::CloudassetV1::WindowsApplication

Contains information about a Windows application that is retrieved from the Windows Registry. For more information about these fields, see: https://docs. microsoft.com/en-us/windows/win32/msi/uninstall-registry-key Corresponds to the JSON property windowsApplication



5932
5933
5934
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5932

def windows_application
  @windows_application
end

#wua_packageGoogle::Apis::CloudassetV1::WindowsUpdatePackage

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated. Corresponds to the JSON property wuaPackage



5940
5941
5942
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5940

def wua_package
  @wua_package
end

#yum_packageGoogle::Apis::CloudassetV1::VersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property yumPackage



5946
5947
5948
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5946

def yum_package
  @yum_package
end

#zypper_packageGoogle::Apis::CloudassetV1::VersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property zypperPackage



5952
5953
5954
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5952

def zypper_package
  @zypper_package
end

#zypper_patchGoogle::Apis::CloudassetV1::ZypperPatch

Details related to a Zypper Patch. Corresponds to the JSON property zypperPatch



5957
5958
5959
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5957

def zypper_patch
  @zypper_patch
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5964

def update!(**args)
  @apt_package = args[:apt_package] if args.key?(:apt_package)
  @cos_package = args[:cos_package] if args.key?(:cos_package)
  @googet_package = args[:googet_package] if args.key?(:googet_package)
  @qfe_package = args[:qfe_package] if args.key?(:qfe_package)
  @windows_application = args[:windows_application] if args.key?(:windows_application)
  @wua_package = args[:wua_package] if args.key?(:wua_package)
  @yum_package = args[:yum_package] if args.key?(:yum_package)
  @zypper_package = args[:zypper_package] if args.key?(:zypper_package)
  @zypper_patch = args[:zypper_patch] if args.key?(:zypper_patch)
end