Class: Google::Apis::CloudassetV1::TemporalAsset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

An asset in Google Cloud and its temporal metadata, including the time window when it was observed and its status during that window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TemporalAsset

Returns a new instance of TemporalAsset.



6160
6161
6162
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetGoogle::Apis::CloudassetV1::Asset

An asset in Google Cloud. An asset can be any resource in the Google Cloud resource hierarchy, a resource outside the Google Cloud resource hierarchy (such as Google Kubernetes Engine clusters and objects), or a policy (e.g. IAM policy), or a relationship (e.g. an INSTANCE_TO_INSTANCEGROUP relationship). See Supported asset types for more information. Corresponds to the JSON property asset



6131
6132
6133
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6131

def asset
  @asset
end

#deletedBoolean Also known as: deleted?

Whether the asset has been deleted or not. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


6136
6137
6138
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6136

def deleted
  @deleted
end

#prior_assetGoogle::Apis::CloudassetV1::Asset

An asset in Google Cloud. An asset can be any resource in the Google Cloud resource hierarchy, a resource outside the Google Cloud resource hierarchy (such as Google Kubernetes Engine clusters and objects), or a policy (e.g. IAM policy), or a relationship (e.g. an INSTANCE_TO_INSTANCEGROUP relationship). See Supported asset types for more information. Corresponds to the JSON property priorAsset



6148
6149
6150
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6148

def prior_asset
  @prior_asset
end

#prior_asset_stateString

State of prior_asset. Corresponds to the JSON property priorAssetState

Returns:

  • (String)


6153
6154
6155
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6153

def prior_asset_state
  @prior_asset_state
end

#windowGoogle::Apis::CloudassetV1::TimeWindow

A time window specified by its start_time and end_time. Corresponds to the JSON property window



6158
6159
6160
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6158

def window
  @window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6165
6166
6167
6168
6169
6170
6171
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6165

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @deleted = args[:deleted] if args.key?(:deleted)
  @prior_asset = args[:prior_asset] if args.key?(:prior_asset)
  @prior_asset_state = args[:prior_asset_state] if args.key?(:prior_asset_state)
  @window = args[:window] if args.key?(:window)
end