Class: Google::Apis::CloudassetV1::WindowsUpdatePackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsUpdatePackage

Returns a new instance of WindowsUpdatePackage.



6471
6472
6473
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::CloudassetV1::WindowsUpdateCategory>

The categories that are associated with this update package. Corresponds to the JSON property categories



6428
6429
6430
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6428

def categories
  @categories
end

#descriptionString

The localized description of the update package. Corresponds to the JSON property description

Returns:

  • (String)


6433
6434
6435
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6433

def description
  @description
end

#kb_article_idsArray<String>

A collection of Microsoft Knowledge Base article IDs that are associated with the update package. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


6439
6440
6441
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6439

def kb_article_ids
  @kb_article_ids
end

#last_deployment_change_timeString

The last published date of the update, in (UTC) date and time. Corresponds to the JSON property lastDeploymentChangeTime

Returns:

  • (String)


6444
6445
6446
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6444

def last_deployment_change_time
  @last_deployment_change_time
end

#more_info_urlsArray<String>

A collection of URLs that provide more information about the update package. Corresponds to the JSON property moreInfoUrls

Returns:

  • (Array<String>)


6449
6450
6451
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6449

def more_info_urls
  @more_info_urls
end

#revision_numberFixnum

The revision number of this update package. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


6454
6455
6456
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6454

def revision_number
  @revision_number
end

#support_urlString

A hyperlink to the language-specific support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


6459
6460
6461
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6459

def support_url
  @support_url
end

#titleString

The localized title of the update package. Corresponds to the JSON property title

Returns:

  • (String)


6464
6465
6466
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6464

def title
  @title
end

#update_idString

Gets the identifier of an update package. Stays the same across revisions. Corresponds to the JSON property updateId

Returns:

  • (String)


6469
6470
6471
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6469

def update_id
  @update_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6476
6477
6478
6479
6480
6481
6482
6483
6484
6485
6486
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6476

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_deployment_change_time = args[:last_deployment_change_time] if args.key?(:last_deployment_change_time)
  @more_info_urls = args[:more_info_urls] if args.key?(:more_info_urls)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
  @update_id = args[:update_id] if args.key?(:update_id)
end