Class: Google::Apis::CloudassetV1::GoogleCloudAssetV1GovernedContainer
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::GoogleCloudAssetV1GovernedContainer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
The organization/folder/project resource governed by organization policies of AnalyzeOrgPolicyGovernedContainersRequest.constraint.
Instance Attribute Summary collapse
-
#consolidated_policy ⇒ Google::Apis::CloudassetV1::AnalyzerOrgPolicy
This organization policy message is a modified version of the one defined in the Organization Policy system.
-
#effective_tags ⇒ Array<Google::Apis::CloudassetV1::EffectiveTagDetails>
The effective tags on this resource.
-
#folders ⇒ Array<String>
The folder(s) that this resource belongs to, in the format of folders/
FOLDER_NUMBER. -
#full_resource_name ⇒ String
The full resource name of an organization/folder/project resource.
-
#organization ⇒ String
The organization that this resource belongs to, in the format of organizations/
ORGANIZATION_NUMBER. -
#parent ⇒ String
The full resource name of the parent of AnalyzeOrgPolicyGovernedContainersResponse.GovernedContainer.
-
#policy_bundle ⇒ Array<Google::Apis::CloudassetV1::AnalyzerOrgPolicy>
The ordered list of all organization policies from the consolidated_policy.
-
#project ⇒ String
The project that this resource belongs to, in the format of projects/
PROJECT_NUMBER.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssetV1GovernedContainer
constructor
A new instance of GoogleCloudAssetV1GovernedContainer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssetV1GovernedContainer
Returns a new instance of GoogleCloudAssetV1GovernedContainer.
1969 1970 1971 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consolidated_policy ⇒ Google::Apis::CloudassetV1::AnalyzerOrgPolicy
This organization policy message is a modified version of the one defined in
the Organization Policy system. This message contains several fields defined
in the original organization policy with some new fields for analysis purpose.
Corresponds to the JSON property consolidatedPolicy
1920 1921 1922 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1920 def consolidated_policy @consolidated_policy end |
#effective_tags ⇒ Array<Google::Apis::CloudassetV1::EffectiveTagDetails>
The effective tags on this resource.
Corresponds to the JSON property effectiveTags
1925 1926 1927 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1925 def @effective_tags end |
#folders ⇒ Array<String>
The folder(s) that this resource belongs to, in the format of folders/
FOLDER_NUMBER. This field is available when the resource belongs (directly or
cascadingly) to one or more folders.
Corresponds to the JSON property folders
1932 1933 1934 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1932 def folders @folders end |
#full_resource_name ⇒ String
The full resource name of an organization/folder/project resource.
Corresponds to the JSON property fullResourceName
1938 1939 1940 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1938 def full_resource_name @full_resource_name end |
#organization ⇒ String
The organization that this resource belongs to, in the format of organizations/
ORGANIZATION_NUMBER. This field is available when the resource belongs (
directly or cascadingly) to an organization.
Corresponds to the JSON property organization
1945 1946 1947 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1945 def organization @organization end |
#parent ⇒ String
The full resource name of the parent of
AnalyzeOrgPolicyGovernedContainersResponse.GovernedContainer.
full_resource_name.
Corresponds to the JSON property parent
1953 1954 1955 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1953 def parent @parent end |
#policy_bundle ⇒ Array<Google::Apis::CloudassetV1::AnalyzerOrgPolicy>
The ordered list of all organization policies from the consolidated_policy.
attached_resource. to the scope specified in the request. If the constraint is
defined with default policy, it will also appear in the list.
Corresponds to the JSON property policyBundle
1960 1961 1962 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1960 def policy_bundle @policy_bundle end |
#project ⇒ String
The project that this resource belongs to, in the format of projects/
PROJECT_NUMBER. This field is available when the resource belongs to a
project.
Corresponds to the JSON property project
1967 1968 1969 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1967 def project @project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 1974 def update!(**args) @consolidated_policy = args[:consolidated_policy] if args.key?(:consolidated_policy) @effective_tags = args[:effective_tags] if args.key?(:effective_tags) @folders = args[:folders] if args.key?(:folders) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @policy_bundle = args[:policy_bundle] if args.key?(:policy_bundle) @project = args[:project] if args.key?(:project) end |