Class: Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
3415 3416 3417 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
Identities can be an individual user, service account, Google group, or third-
party identity. For third-party identity, only single identities are supported
and other identity types are not supported. The v1 identities that have the
prefix user, group, serviceAccount, and principal in https://cloud.
google.com/iam/docs/principal-identifiers#v1 are supported.
Corresponds to the JSON property identities
3401 3402 3403 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3401 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
3408 3409 3410 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3408 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
3413 3414 3415 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3413 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3420 3421 3422 3423 3424 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3420 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |