Class: Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
Specifies how APIs are allowed to communicate within the Service Perimeter.
Instance Attribute Summary collapse
-
#allowed_service_patterns ⇒ Array<Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1ServicePattern>
Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter.
-
#allowed_services ⇒ Array<String>
The list of APIs usable within the Service Perimeter.
-
#enable_restriction ⇒ Boolean
(also: #enable_restriction?)
Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'.
-
#service_patterns_enforcement_scopes ⇒ Array<String>
Defines the enforcement scopes of service patterns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices
Returns a new instance of GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices.
3912 3913 3914 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_service_patterns ⇒ Array<Google::Apis::CloudassetV1::GoogleIdentityAccesscontextmanagerV1ServicePattern>
Specifies which Google services are allowed to be accessed from VPC networks
in the service perimeter.
Corresponds to the JSON property allowedServicePatterns
3890 3891 3892 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3890 def allowed_service_patterns @allowed_service_patterns end |
#allowed_services ⇒ Array<String>
The list of APIs usable within the Service Perimeter. Must be empty unless '
enable_restriction' is True. You can specify a list of individual services, as
well as include the 'RESTRICTED-SERVICES' value, which automatically includes
all of the services protected by the perimeter.
Corresponds to the JSON property allowedServices
3898 3899 3900 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3898 def allowed_services @allowed_services end |
#enable_restriction ⇒ Boolean Also known as: enable_restriction?
Whether to restrict API calls within the Service Perimeter to the list of APIs
specified in 'allowed_services'.
Corresponds to the JSON property enableRestriction
3904 3905 3906 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3904 def enable_restriction @enable_restriction end |
#service_patterns_enforcement_scopes ⇒ Array<String>
Defines the enforcement scopes of service patterns.
Corresponds to the JSON property servicePatternsEnforcementScopes
3910 3911 3912 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3910 def service_patterns_enforcement_scopes @service_patterns_enforcement_scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3917 3918 3919 3920 3921 3922 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3917 def update!(**args) @allowed_service_patterns = args[:allowed_service_patterns] if args.key?(:allowed_service_patterns) @allowed_services = args[:allowed_services] if args.key?(:allowed_services) @enable_restriction = args[:enable_restriction] if args.key?(:enable_restriction) @service_patterns_enforcement_scopes = args[:service_patterns_enforcement_scopes] if args.key?(:service_patterns_enforcement_scopes) end |