Class: Google::Apis::CloudassetV1::IamPolicyAnalysisQuery
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::IamPolicyAnalysisQuery
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
IAM policy analysis query message.
Instance Attribute Summary collapse
-
#access_selector ⇒ Google::Apis::CloudassetV1::AccessSelector
Specifies roles and/or permissions to analyze, to determine both the identities possessing them and the resources they control.
-
#condition_context ⇒ Google::Apis::CloudassetV1::ConditionContext
The IAM conditions context.
-
#identity_selector ⇒ Google::Apis::CloudassetV1::IdentitySelector
Specifies an identity for which to determine resource access, based on roles assigned either directly to them or to the groups they belong to, directly or indirectly.
-
#options ⇒ Google::Apis::CloudassetV1::Options
Contains query options.
-
#resource_selector ⇒ Google::Apis::CloudassetV1::ResourceSelector
Specifies the resource to analyze for access policies, which may be set directly on the resource, or on ancestors such as organizations, folders or projects.
-
#scope ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IamPolicyAnalysisQuery
constructor
A new instance of IamPolicyAnalysisQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IamPolicyAnalysisQuery
Returns a new instance of IamPolicyAnalysisQuery.
3969 3970 3971 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_selector ⇒ Google::Apis::CloudassetV1::AccessSelector
Specifies roles and/or permissions to analyze, to determine both the
identities possessing them and the resources they control. If multiple values
are specified, results will include roles or permissions matching any of them.
The total number of roles and permissions should be equal or less than 10.
Corresponds to the JSON property accessSelector
3930 3931 3932 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3930 def access_selector @access_selector end |
#condition_context ⇒ Google::Apis::CloudassetV1::ConditionContext
The IAM conditions context.
Corresponds to the JSON property conditionContext
3935 3936 3937 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3935 def condition_context @condition_context end |
#identity_selector ⇒ Google::Apis::CloudassetV1::IdentitySelector
Specifies an identity for which to determine resource access, based on roles
assigned either directly to them or to the groups they belong to, directly or
indirectly.
Corresponds to the JSON property identitySelector
3942 3943 3944 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3942 def identity_selector @identity_selector end |
#options ⇒ Google::Apis::CloudassetV1::Options
Contains query options.
Corresponds to the JSON property options
3947 3948 3949 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3947 def @options end |
#resource_selector ⇒ Google::Apis::CloudassetV1::ResourceSelector
Specifies the resource to analyze for access policies, which may be set
directly on the resource, or on ancestors such as organizations, folders or
projects.
Corresponds to the JSON property resourceSelector
3954 3955 3956 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3954 def resource_selector @resource_selector end |
#scope ⇒ String
Required. The relative name of the root asset. Only resources and IAM policies
within the scope will be analyzed. This can only be an organization number (
such as "organizations/123"), a folder number (such as "folders/123"), a
project ID (such as "projects/my-project-id"), or a project number (such as "
projects/12345"). To know how to get organization ID, visit here . To know how to get folder or project ID,
visit here .
Corresponds to the JSON property scope
3967 3968 3969 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3967 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3974 3975 3976 3977 3978 3979 3980 3981 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 3974 def update!(**args) @access_selector = args[:access_selector] if args.key?(:access_selector) @condition_context = args[:condition_context] if args.key?(:condition_context) @identity_selector = args[:identity_selector] if args.key?(:identity_selector) @options = args[:options] if args.key?(:options) @resource_selector = args[:resource_selector] if args.key?(:resource_selector) @scope = args[:scope] if args.key?(:scope) end |