Class: Google::Apis::CloudassetV1::Inventory
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::Inventory
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
This API resource represents the available inventory data for a Compute Engine virtual machine (VM) instance at a given point in time. You can use this API resource to determine the inventory data of your VM. For more information, see Information provided by OS inventory management.
Instance Attribute Summary collapse
-
#items ⇒ Hash<String,Google::Apis::CloudassetV1::Item>
Inventory items related to the VM keyed by an opaque unique identifier for each inventory item.
-
#name ⇒ String
Output only.
-
#os_info ⇒ Google::Apis::CloudassetV1::OsInfo
Operating system information for the VM.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Inventory
constructor
A new instance of Inventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Inventory
Returns a new instance of Inventory.
4219 4220 4221 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Hash<String,Google::Apis::CloudassetV1::Item>
Inventory items related to the VM keyed by an opaque unique identifier for
each inventory item. The identifier is unique to each distinct and addressable
inventory item and will change, when there is a new package version.
Corresponds to the JSON property items
4201 4202 4203 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4201 def items @items end |
#name ⇒ String
Output only. The Inventory API resource name. Format: projects/
project_number/locations/location/instances/instance_id/inventory
Corresponds to the JSON property name
4207 4208 4209 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4207 def name @name end |
#os_info ⇒ Google::Apis::CloudassetV1::OsInfo
Operating system information for the VM.
Corresponds to the JSON property osInfo
4212 4213 4214 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4212 def os_info @os_info end |
#update_time ⇒ String
Output only. Timestamp of the last reported inventory for the VM.
Corresponds to the JSON property updateTime
4217 4218 4219 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4217 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4224 4225 4226 4227 4228 4229 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4224 def update!(**args) @items = args[:items] if args.key?(:items) @name = args[:name] if args.key?(:name) @os_info = args[:os_info] if args.key?(:os_info) @update_time = args[:update_time] if args.key?(:update_time) end |