Class: Google::Apis::CloudassetV1::ListAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

ListAssets response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssetsResponse

Returns a new instance of ListAssetsResponse.



4308
4309
4310
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetsArray<Google::Apis::CloudassetV1::Asset>

Assets. Corresponds to the JSON property assets



4294
4295
4296
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4294

def assets
  @assets
end

#next_page_tokenString

Token to retrieve the next page of results. It expires 72 hours after the page token for the first page is generated. Set to empty if there are no remaining results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4301
4302
4303
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4301

def next_page_token
  @next_page_token
end

#read_timeString

Time the snapshot was taken. Corresponds to the JSON property readTime

Returns:

  • (String)


4306
4307
4308
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4306

def read_time
  @read_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4313
4314
4315
4316
4317
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4313

def update!(**args)
  @assets = args[:assets] if args.key?(:assets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @read_time = args[:read_time] if args.key?(:read_time)
end