Class: Google::Apis::CloudassetV1::MoveAnalysis

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

A message to group the analysis information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveAnalysis

Returns a new instance of MoveAnalysis.



4390
4391
4392
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisGoogle::Apis::CloudassetV1::MoveAnalysisResult

An analysis result including blockers and warnings. Corresponds to the JSON property analysis



4372
4373
4374
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4372

def analysis
  @analysis
end

#display_nameString

The user friendly display name of the analysis. E.g. IAM, organization policy etc. Corresponds to the JSON property displayName

Returns:

  • (String)


4378
4379
4380
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4378

def display_name
  @display_name
end

#errorGoogle::Apis::CloudassetV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4388
4389
4390
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4388

def error
  @error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4395
4396
4397
4398
4399
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4395

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
end