Class: Google::Apis::CloudassetV1::MoveAnalysisResult
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::MoveAnalysisResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
An analysis result including blockers and warnings.
Instance Attribute Summary collapse
-
#blockers ⇒ Array<Google::Apis::CloudassetV1::MoveImpact>
Blocking information that would prevent the target resource from moving to the specified destination at runtime.
-
#warnings ⇒ Array<Google::Apis::CloudassetV1::MoveImpact>
Warning information indicating that moving the target resource to the specified destination might be unsafe.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveAnalysisResult
constructor
A new instance of MoveAnalysisResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveAnalysisResult
Returns a new instance of MoveAnalysisResult.
4542 4543 4544 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blockers ⇒ Array<Google::Apis::CloudassetV1::MoveImpact>
Blocking information that would prevent the target resource from moving to the
specified destination at runtime.
Corresponds to the JSON property blockers
4533 4534 4535 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4533 def blockers @blockers end |
#warnings ⇒ Array<Google::Apis::CloudassetV1::MoveImpact>
Warning information indicating that moving the target resource to the
specified destination might be unsafe. This can include important policy
information and configuration changes, but will not block moves at runtime.
Corresponds to the JSON property warnings
4540 4541 4542 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4540 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4547 4548 4549 4550 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4547 def update!(**args) @blockers = args[:blockers] if args.key?(:blockers) @warnings = args[:warnings] if args.key?(:warnings) end |