Class: Google::Apis::CloudassetV1::OrgPolicyResult
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::OrgPolicyResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
The organization policy result to the query.
Instance Attribute Summary collapse
-
#consolidated_policy ⇒ Google::Apis::CloudassetV1::AnalyzerOrgPolicy
This organization policy message is a modified version of the one defined in the Organization Policy system.
-
#folders ⇒ Array<String>
The folder(s) that this consolidated policy belongs to, in the format of folders/
FOLDER_NUMBER. -
#organization ⇒ String
The organization that this consolidated policy belongs to, in the format of organizations/
ORGANIZATION_NUMBER. -
#policy_bundle ⇒ Array<Google::Apis::CloudassetV1::AnalyzerOrgPolicy>
The ordered list of all organization policies from the consolidated_policy.
-
#project ⇒ String
The project that this consolidated policy belongs to, in the format of projects/
PROJECT_NUMBER.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrgPolicyResult
constructor
A new instance of OrgPolicyResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrgPolicyResult
Returns a new instance of OrgPolicyResult.
4652 4653 4654 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consolidated_policy ⇒ Google::Apis::CloudassetV1::AnalyzerOrgPolicy
This organization policy message is a modified version of the one defined in
the Organization Policy system. This message contains several fields defined
in the original organization policy with some new fields for analysis purpose.
Corresponds to the JSON property consolidatedPolicy
4622 4623 4624 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4622 def consolidated_policy @consolidated_policy end |
#folders ⇒ Array<String>
The folder(s) that this consolidated policy belongs to, in the format of
folders/FOLDER_NUMBER. This field is available when the consolidated policy
belongs (directly or cascadingly) to one or more folders.
Corresponds to the JSON property folders
4629 4630 4631 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4629 def folders @folders end |
#organization ⇒ String
The organization that this consolidated policy belongs to, in the format of
organizations/ORGANIZATION_NUMBER. This field is available when the
consolidated policy belongs (directly or cascadingly) to an organization.
Corresponds to the JSON property organization
4636 4637 4638 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4636 def organization @organization end |
#policy_bundle ⇒ Array<Google::Apis::CloudassetV1::AnalyzerOrgPolicy>
The ordered list of all organization policies from the consolidated_policy.
attached_resource. to the scope specified in the request. If the constraint is
defined with default policy, it will also appear in the list.
Corresponds to the JSON property policyBundle
4643 4644 4645 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4643 def policy_bundle @policy_bundle end |
#project ⇒ String
The project that this consolidated policy belongs to, in the format of
projects/PROJECT_NUMBER. This field is available when the consolidated
policy belongs to a project.
Corresponds to the JSON property project
4650 4651 4652 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4650 def project @project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4657 4658 4659 4660 4661 4662 4663 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4657 def update!(**args) @consolidated_policy = args[:consolidated_policy] if args.key?(:consolidated_policy) @folders = args[:folders] if args.key?(:folders) @organization = args[:organization] if args.key?(:organization) @policy_bundle = args[:policy_bundle] if args.key?(:policy_bundle) @project = args[:project] if args.key?(:project) end |