Class: Google::Apis::CloudassetV1::QueryAssetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::QueryAssetsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
QueryAssets request.
Instance Attribute Summary collapse
-
#job_reference ⇒ String
Optional.
-
#output_config ⇒ Google::Apis::CloudassetV1::QueryAssetsOutputConfig
Output configuration query assets.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#read_time ⇒ String
Optional.
-
#read_time_window ⇒ Google::Apis::CloudassetV1::TimeWindow
A time window specified by its
start_timeandend_time. -
#statement ⇒ String
Optional.
-
#timeout ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryAssetsRequest
constructor
A new instance of QueryAssetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryAssetsRequest
Returns a new instance of QueryAssetsRequest.
5034 5035 5036 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_reference ⇒ String
Optional. Reference to the query job, which is from the QueryAssetsResponse
of previous QueryAssets call.
Corresponds to the JSON property jobReference
4984 4985 4986 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4984 def job_reference @job_reference end |
#output_config ⇒ Google::Apis::CloudassetV1::QueryAssetsOutputConfig
Output configuration query assets.
Corresponds to the JSON property outputConfig
4989 4990 4991 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4989 def output_config @output_config end |
#page_size ⇒ Fixnum
Optional. The maximum number of rows to return in the results. Responses are
limited to 10 MB and 1000 rows. By default, the maximum row count is 1000.
When the byte or row count limit is reached, the rest of the query results
will be paginated. The field will be ignored when [output_config] is specified.
Corresponds to the JSON property pageSize
4997 4998 4999 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 4997 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token received from previous QueryAssets. The field will be
ignored when [output_config] is specified.
Corresponds to the JSON property pageToken
5003 5004 5005 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5003 def page_token @page_token end |
#read_time ⇒ String
Optional. Queries cloud assets as they appeared at the specified point in time.
Corresponds to the JSON property readTime
5008 5009 5010 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5008 def read_time @read_time end |
#read_time_window ⇒ Google::Apis::CloudassetV1::TimeWindow
A time window specified by its start_time and end_time.
Corresponds to the JSON property readTimeWindow
5013 5014 5015 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5013 def read_time_window @read_time_window end |
#statement ⇒ String
Optional. A SQL statement that's compatible with BigQuery SQL.
Corresponds to the JSON property statement
5019 5020 5021 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5019 def statement @statement end |
#timeout ⇒ String
Optional. Specifies the maximum amount of time that the client is willing to
wait for the query to complete. By default, this limit is 5 min for the first
query, and 1 minute for the following queries. If the query is complete, the
done field in the QueryAssetsResponse is true, otherwise false. Like
BigQuery jobs.query API The call is not guaranteed to wait for the
specified timeout; it typically returns after around 200 seconds (200,000
milliseconds), even if the query is not complete. The field will be ignored
when [output_config] is specified.
Corresponds to the JSON property timeout
5032 5033 5034 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5032 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5039 def update!(**args) @job_reference = args[:job_reference] if args.key?(:job_reference) @output_config = args[:output_config] if args.key?(:output_config) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @read_time = args[:read_time] if args.key?(:read_time) @read_time_window = args[:read_time_window] if args.key?(:read_time_window) @statement = args[:statement] if args.key?(:statement) @timeout = args[:timeout] if args.key?(:timeout) end |