Class: Google::Apis::CloudassetV1::QueryAssetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::QueryAssetsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
QueryAssets response.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
The query response, which can be either an
erroror a validresponse. -
#error ⇒ Google::Apis::CloudassetV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_reference ⇒ String
Reference to a query job.
-
#output_config ⇒ Google::Apis::CloudassetV1::QueryAssetsOutputConfig
Output configuration query assets.
-
#query_result ⇒ Google::Apis::CloudassetV1::QueryResult
Execution results of the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryAssetsResponse
constructor
A new instance of QueryAssetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryAssetsResponse
Returns a new instance of QueryAssetsResponse.
5215 5216 5217 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
The query response, which can be either an error or a valid response. If
done == false and the query result is being saved in an output, the
output_config field will be set. If done == true, exactly one of error,
query_result or output_config will be set. [done] is unset unless the [
QueryAssetsResponse] contains a [QueryAssetsResponse.job_reference].
Corresponds to the JSON property done
5185 5186 5187 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5185 def done @done end |
#error ⇒ Google::Apis::CloudassetV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
5196 5197 5198 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5196 def error @error end |
#job_reference ⇒ String
Reference to a query job.
Corresponds to the JSON property jobReference
5201 5202 5203 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5201 def job_reference @job_reference end |
#output_config ⇒ Google::Apis::CloudassetV1::QueryAssetsOutputConfig
Output configuration query assets.
Corresponds to the JSON property outputConfig
5206 5207 5208 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5206 def output_config @output_config end |
#query_result ⇒ Google::Apis::CloudassetV1::QueryResult
Execution results of the query. The result is formatted as rows represented by
BigQuery compatible [schema]. When pagination is necessary, it will contains
the page token to retrieve the results of following pages.
Corresponds to the JSON property queryResult
5213 5214 5215 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5213 def query_result @query_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5220 5221 5222 5223 5224 5225 5226 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5220 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @job_reference = args[:job_reference] if args.key?(:job_reference) @output_config = args[:output_config] if args.key?(:output_config) @query_result = args[:query_result] if args.key?(:query_result) end |