Class: Google::Apis::CloudassetV1::QueryAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

QueryAssets response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryAssetsResponse

Returns a new instance of QueryAssetsResponse.



5092
5093
5094
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

The query response, which can be either an error or a valid response. If done == false and the query result is being saved in an output, the output_config field will be set. If done == true, exactly one of error, query_result or output_config will be set. [done] is unset unless the [ QueryAssetsResponse] contains a [QueryAssetsResponse.job_reference]. Corresponds to the JSON property done

Returns:

  • (Boolean)


5062
5063
5064
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5062

def done
  @done
end

#errorGoogle::Apis::CloudassetV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5073
5074
5075
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5073

def error
  @error
end

#job_referenceString

Reference to a query job. Corresponds to the JSON property jobReference

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5078

def job_reference
  @job_reference
end

#output_configGoogle::Apis::CloudassetV1::QueryAssetsOutputConfig

Output configuration query assets. Corresponds to the JSON property outputConfig



5083
5084
5085
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5083

def output_config
  @output_config
end

#query_resultGoogle::Apis::CloudassetV1::QueryResult

Execution results of the query. The result is formatted as rows represented by BigQuery compatible [schema]. When pagination is necessary, it will contains the page token to retrieve the results of following pages. Corresponds to the JSON property queryResult



5090
5091
5092
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5090

def query_result
  @query_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5097
5098
5099
5100
5101
5102
5103
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5097

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @job_reference = args[:job_reference] if args.key?(:job_reference)
  @output_config = args[:output_config] if args.key?(:output_config)
  @query_result = args[:query_result] if args.key?(:query_result)
end