Class: Google::Apis::CloudassetV1::Resource
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::Resource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
A representation of a Google Cloud resource.
Instance Attribute Summary collapse
-
#data ⇒ Hash<String,Object>
The content of the resource, in which some sensitive fields are removed and may not be present.
-
#discovery_document_uri ⇒ String
The URL of the discovery document containing the resource's JSON schema.
-
#discovery_name ⇒ String
The JSON schema name listed in the discovery document.
-
#location ⇒ String
The location of the resource in Google Cloud, such as its zone and region.
-
#parent ⇒ String
The full name of the immediate parent of this resource.
-
#resource_url ⇒ String
The REST URL for accessing the resource.
-
#version ⇒ String
The API version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
5387 5388 5389 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Hash<String,Object>
The content of the resource, in which some sensitive fields are removed and
may not be present.
Corresponds to the JSON property data
5341 5342 5343 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5341 def data @data end |
#discovery_document_uri ⇒ String
The URL of the discovery document containing the resource's JSON schema.
Example: https://www.googleapis.com/discovery/v1/apis/compute/v1/rest This
value is unspecified for resources that do not have an API based on a
discovery document, such as Cloud Bigtable.
Corresponds to the JSON property discoveryDocumentUri
5349 5350 5351 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5349 def discovery_document_uri @discovery_document_uri end |
#discovery_name ⇒ String
The JSON schema name listed in the discovery document. Example: Project This
value is unspecified for resources that do not have an API based on a
discovery document, such as Cloud Bigtable.
Corresponds to the JSON property discoveryName
5356 5357 5358 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5356 def discovery_name @discovery_name end |
#location ⇒ String
The location of the resource in Google Cloud, such as its zone and region. For
more information, see https://cloud.google.com/about/locations/.
Corresponds to the JSON property location
5362 5363 5364 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5362 def location @location end |
#parent ⇒ String
The full name of the immediate parent of this resource. See Resource Names for
more information. For Google Cloud assets, this value is the parent resource
defined in the IAM policy hierarchy. Example: //cloudresourcemanager.googleapis.com/
projects/my_project_123
Corresponds to the JSON property parent
5372 5373 5374 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5372 def parent @parent end |
#resource_url ⇒ String
The REST URL for accessing the resource. An HTTP GET request using this URL
returns the resource itself. Example: https://cloudresourcemanager.googleapis.
com/v1/projects/my-project-123 This value is unspecified for resources
without a REST API.
Corresponds to the JSON property resourceUrl
5380 5381 5382 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5380 def resource_url @resource_url end |
#version ⇒ String
The API version. Example: v1
Corresponds to the JSON property version
5385 5386 5387 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5385 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5392 5393 5394 5395 5396 5397 5398 5399 5400 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5392 def update!(**args) @data = args[:data] if args.key?(:data) @discovery_document_uri = args[:discovery_document_uri] if args.key?(:discovery_document_uri) @discovery_name = args[:discovery_name] if args.key?(:discovery_name) @location = args[:location] if args.key?(:location) @parent = args[:parent] if args.key?(:parent) @resource_url = args[:resource_url] if args.key?(:resource_url) @version = args[:version] if args.key?(:version) end |