Class: Google::Apis::CloudassetV1::SavedQuery
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::SavedQuery
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
A saved query which can be shared with others or used later.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::CloudassetV1::QueryContent
The query content.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#description ⇒ String
The description of this saved query.
-
#labels ⇒ Hash<String,String>
Labels applied on the resource.
-
#last_update_time ⇒ String
Output only.
-
#last_updater ⇒ String
Output only.
-
#name ⇒ String
The resource name of the saved query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedQuery
constructor
A new instance of SavedQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedQuery
Returns a new instance of SavedQuery.
5948 5949 5950 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::CloudassetV1::QueryContent
The query content.
Corresponds to the JSON property content
5904 5905 5906 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5904 def content @content end |
#create_time ⇒ String
Output only. The create time of this saved query.
Corresponds to the JSON property createTime
5909 5910 5911 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5909 def create_time @create_time end |
#creator ⇒ String
Output only. The account's email address who has created this saved query.
Corresponds to the JSON property creator
5914 5915 5916 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5914 def creator @creator end |
#description ⇒ String
The description of this saved query. This value should be fewer than 255
characters.
Corresponds to the JSON property description
5920 5921 5922 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5920 def description @description end |
#labels ⇒ Hash<String,String>
Labels applied on the resource. This value should not contain more than 10
entries. The key and value of each entry must be non-empty and fewer than 64
characters.
Corresponds to the JSON property labels
5927 5928 5929 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5927 def labels @labels end |
#last_update_time ⇒ String
Output only. The last update time of this saved query.
Corresponds to the JSON property lastUpdateTime
5932 5933 5934 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5932 def last_update_time @last_update_time end |
#last_updater ⇒ String
Output only. The account's email address who has updated this saved query most
recently.
Corresponds to the JSON property lastUpdater
5938 5939 5940 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5938 def last_updater @last_updater end |
#name ⇒ String
The resource name of the saved query. The format must be: * projects/
project_number/savedQueries/saved_query_id * folders/folder_number/
savedQueries/saved_query_id * organizations/organization_number/savedQueries/
saved_query_id
Corresponds to the JSON property name
5946 5947 5948 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5946 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5953 def update!(**args) @content = args[:content] if args.key?(:content) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @last_updater = args[:last_updater] if args.key?(:last_updater) @name = args[:name] if args.key?(:name) end |