Class: Google::Apis::CloudassetV1::SearchAllIamPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::SearchAllIamPoliciesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
Search all IAM policies response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Set if there are more results than those appearing in this response; to get the next set of results, call this method again, using this value as the
page_token. -
#results ⇒ Array<Google::Apis::CloudassetV1::IamPolicySearchResult>
A list of IAM policies that match the search query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchAllIamPoliciesResponse
constructor
A new instance of SearchAllIamPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchAllIamPoliciesResponse
Returns a new instance of SearchAllIamPoliciesResponse.
5982 5983 5984 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Set if there are more results than those appearing in this response; to get
the next set of results, call this method again, using this value as the
page_token.
Corresponds to the JSON property nextPageToken
5974 5975 5976 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5974 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::CloudassetV1::IamPolicySearchResult>
A list of IAM policies that match the search query. Related information such
as the associated resource is returned along with the policy.
Corresponds to the JSON property results
5980 5981 5982 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5980 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5987 5988 5989 5990 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 5987 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |