Class: Google::Apis::CloudassetV1::UpdateFeedRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1::UpdateFeedRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb
Overview
Update asset feed request.
Instance Attribute Summary collapse
-
#feed ⇒ Google::Apis::CloudassetV1::Feed
An asset feed used to export asset updates to a destinations.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateFeedRequest
constructor
A new instance of UpdateFeedRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateFeedRequest
Returns a new instance of UpdateFeedRequest.
6342 6343 6344 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feed ⇒ Google::Apis::CloudassetV1::Feed
An asset feed used to export asset updates to a destinations. An asset feed
filter controls what updates are exported. The asset feed must be created
within a project, organization, or folder. Supported destinations are: Pub/Sub
topics.
Corresponds to the JSON property feed
6333 6334 6335 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6333 def feed @feed end |
#update_mask ⇒ String
Required. Only updates the feed fields indicated by this mask. The field
mask must not be empty, and it must not contain fields that are immutable or
only set by the server.
Corresponds to the JSON property updateMask
6340 6341 6342 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6340 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6347 6348 6349 6350 |
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6347 def update!(**args) @feed = args[:feed] if args.key?(:feed) @update_mask = args[:update_mask] if args.key?(:update_mask) end |