Class: Google::Apis::CloudassetV1::UpdateFeedRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1/classes.rb,
lib/google/apis/cloudasset_v1/representations.rb,
lib/google/apis/cloudasset_v1/representations.rb

Overview

Update asset feed request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateFeedRequest

Returns a new instance of UpdateFeedRequest.



6219
6220
6221
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feedGoogle::Apis::CloudassetV1::Feed

An asset feed used to export asset updates to a destinations. An asset feed filter controls what updates are exported. The asset feed must be created within a project, organization, or folder. Supported destinations are: Pub/Sub topics. Corresponds to the JSON property feed



6210
6211
6212
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6210

def feed
  @feed
end

#update_maskString

Required. Only updates the feed fields indicated by this mask. The field mask must not be empty, and it must not contain fields that are immutable or only set by the server. Corresponds to the JSON property updateMask

Returns:

  • (String)


6217
6218
6219
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6217

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6224
6225
6226
6227
# File 'lib/google/apis/cloudasset_v1/classes.rb', line 6224

def update!(**args)
  @feed = args[:feed] if args.key?(:feed)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end